<?php

namespace Drupal\widget_provider_example\Plugin\WidgetProvider;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\Entity\User;
use Drupal\widget_provider_api\Attribute\WidgetProvider;
use Drupal\widget_provider_api\WidgetProviderBase;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * A Node Widget Example class.
 */
#[WidgetProvider(
  id: 'widget-provider-example:widget-provider-node-example',
  label: new TranslatableMarkup('Widget Provider Node Example'),
  description: new TranslatableMarkup('Renders a Node as a widget.'),
  requiredParameters: ['nid'],
  optionalParameters: ['test'],
)]
class WidgetProviderDrupalNodeExample extends WidgetProviderBase {

  /**
   * {@inheritdoc}
   */
  public function buildContent() {
    $nid = $this->getParameterValue('nid', FALSE);
    return $this->buildNode($nid);
  }

  /**
   * Node render function, for creating a node widget.
   *
   * @param string $entity_id
   *   The entity id.
   *
   * @return array
   *   The node render array.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException
   *   Thrown when access is denied.
   */
  public function buildNode($entity_id) {
    $current_user = \Drupal::currentUser();
    $user = User::load($current_user->id());
    $entity = \Drupal::entityTypeManager()->getStorage('node')->load($entity_id);
    if ($entity->access('view', $user)) {
      $view_builder = \Drupal::entityTypeManager()->getViewBuilder('node');
      $pre_render = $view_builder->view($entity);
      return $pre_render;
    }
    throw new AccessDeniedHttpException("You don't have access to this Node!!");
  }

}
