<?php

namespace Drupal\widget_provider_example\Plugin\WidgetProvider;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\views\Views;
use Drupal\widget_provider_api\Attribute\WidgetProvider;
use Drupal\widget_provider_api\WidgetProviderBase;

/**
 * A View Widget Example class.
 */
#[WidgetProvider(
  id: 'widget-provider-example:widget-provider-view-example',
  label: new TranslatableMarkup('Widget Provider View Example'),
  description: new TranslatableMarkup('Renders a View as a widget.'),
)]
class WidgetProviderDrupalViewExample extends WidgetProviderBase {

  /**
   * {@inheritdoc}
   */
  public function buildContent() {
    return $this->buildView('frontpage');
  }

  /**
   * Function for rendering the View.
   *
   * @param string $viewName
   *   The name of the view.
   * @param string $display
   *   The display ID.
   *
   * @return array
   *   The view render array.
   */
  public function buildView($viewName, $display = 'default') {
    $view = Views::getView($viewName);
    if (is_object($view)) {
      $view->setDisplay($display);
      $view->preExecute();
      $view->execute();
      return $view->buildRenderable();
    }
  }

}
