<?php

namespace Drupal\Tests\widget_provider_example\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\widget_provider_api\WidgetProviderBase;

/**
 * Tests UI elements of the WidgetProviderApi Examples.
 *
 * @group widget_provider_example
 */
class WidgetExampleFunctionalTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'user',
    'node',
    'views',
    'widget_provider_api',
    'widget_provider_example',
  ];

  /**
   * Plain theme with no styling for better testing.
   *
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the view example widget.
   */
  public function testViewExample() {
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-view-example');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('No front page content has been created yet.');
  }

  /**
   * Tests the node example widget.
   */
  public function testNodeExample() {
    // Create a test node type + node::
    $this->createContentType(['type' => 'article']);
    $node = $this->createNode([
      'type' => 'article',
      'body' => ['value' => 'This is an example text.'],
    ]);
    // If the required parameter is not set, we should get a 404:
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-node-example');
    $this->assertSession()->statusCodeEquals(404);
    // Check if providing the required parameter works. the optional parameters
    // shouldn't matter:
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-node-example', [
      'query' => ['nid' => (string) $node->id()],
    ]);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains($node->body->value);
    // Now with the optional parameter:
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-node-example', [
      'query' => ['nid' => (string) $node->id(), 'test' => 'test123'],
    ]);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains($node->body->value);
  }

  /**
   * Tests to see if the Widget IFrame Example url exists.
   */
  public function testIframeExampleWorks() {
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-iframe-example');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementAttributeExists('css', 'iframe', 'src');
    $this->assertSession()->elementAttributeContains('css', 'iframe', 'src', 'https://www.google.com/');
  }

  /**
   * Tests the Iframe Secret Example.
   */
  public function testIframeExampleWithSecretWorks() {
    // Without providing a secret, we should get a 404:
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-iframe-secret-example');
    $this->assertSession()->statusCodeEquals(404);
    // Providing the secret should work:
    $checksumSecret = WidgetProviderBase::generateUrl('my-well-kept-secret', 'widget-provider-example:widget-provider-iframe-secret-example', ['req']);
    $this->drupalGet($checksumSecret);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementAttributeExists('css', 'iframe', 'src');
    $this->assertSession()->elementAttributeContains('css', 'iframe', 'src', 'https://www.google.com/');
  }

  /**
   * Tests the json example.
   */
  public function testJsonExample() {
    $this->drupalGet('/widget-provider/widget-provider-example/widget-provider-json-example');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->responseContains('This is an example from JSON Example');
  }

  /**
   * Tests if some random Widget doesn't exist.
   */
  public function testWidgetDoesNotExist() {
    $this->drupalGet('/widget-provider/widget-provider-example/my-random-widget');
    $this->assertSession()->statusCodeEquals(404);
  }

}
