<?php

declare(strict_types=1);

namespace Drupal\widget_provider_api\Attribute;

use Drupal\Component\Plugin\Attribute\AttributeBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * The widget provider attribute.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
final class WidgetProvider extends AttributeBase {

  /**
   * Constructs a new Widget Provider instance.
   *
   * @param string $id
   *   The plugin ID. The plugin id must be set in the format "group:plugin_id",
   *   where "group" is the base ID and "plugin_id" is the derivative ID.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $label
   *   (optional) The human-readable name of the plugin.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $description
   *   (optional) A brief description of the plugin.
   * @param array $requiredParameters
   *   (optional) An array of required parameters.
   * @param array $optionalParameters
   *   (optional) An array of optional parameters.
   * @param array $allowedReferrers
   *   (optional) An array of allowed referrers.
   * @param string $secret
   *   (optional) The secret used to authenticate the widget provider.
   */
  public function __construct(
    public readonly string $id,
    public readonly ?TranslatableMarkup $label,
    public readonly ?TranslatableMarkup $description = NULL,
    public readonly array $requiredParameters = [],
    public readonly array $optionalParameters = [],
    public readonly array $allowedReferrers = [],
    public readonly ?string $secret = NULL,
  ) {}

}
