<?php

declare(strict_types=1);

namespace Drupal\widget_provider_api;

use Drupal\Component\Plugin\Factory\DefaultFactory;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\widget_provider_api\Attribute\WidgetProvider;

/**
 * Widget plugin manager.
 */
final class WidgetProviderPluginManager extends DefaultPluginManager {

  /**
   * Constructs the object.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/WidgetProvider', $namespaces, $module_handler, WidgetProviderInterface::class, WidgetProvider::class);
    $this->alterInfo('widget_provider_info');
    $this->setCacheBackend($cache_backend, 'widget_provider_plugins');
  }

  /**
   * {@inheritdoc}
   *
   * We need to override this, to support "ContainerFactoryPluginInterface"
   * instances.
   */
  public function createInstance($plugin_id, array $configuration = []) {
    $plugin_definition = $this->getDefinition($plugin_id);
    $plugin_class = DefaultFactory::getPluginClass($plugin_id, $plugin_definition);

    // If the plugin provides a factory method, pass the container to it.
    if (is_subclass_of($plugin_class, 'Drupal\Core\Plugin\ContainerFactoryPluginInterface')) {
      return $plugin_class::create(\Drupal::getContainer(), $configuration, $plugin_id, $plugin_definition);
    }
    return new $plugin_class($plugin_id, $plugin_definition, $configuration['queryParameters'], $configuration['secret'], $configuration['referer']);
  }

}
